@@ -14,7 +14,6 @@
 #include <signal.h>
 #include <time.h>
 #include <sys/time.h>
-#include <termios.h>
 #ifndef S_SPLINT_S
 #include <unistd.h>
 #endif /* S_SPLINT_S */
@@ -26,7 +25,7 @@ static int debuglevel;
 static unsigned int timeout = 8;
 
 /*
- * Set this as high or higher than the maximum number of subtype 
+ * Set this as high or higher than the maximum number of subtype
  * probes in drivers.c.
  */
 #define REDIRECT_SNIFF	15
@@ -119,7 +118,7 @@ static gps_mask_t get_packet(struct gps_device_t *session)
 	    if (errno == EINTR || !FD_ISSET(session->gpsdata.gps_fd, &rfds))
 		continue;
 	    gpsd_report(LOG_ERROR, "select %s\n", strerror(errno));
-	    exit(2);
+	    exit(EXIT_FAILURE);
 	}
 	/*@ +usedef +type +nullpass +compdef @*/
 
@@ -148,7 +147,7 @@ static void settle(struct gps_device_t *session)
     (void)tcdrain(session->gpsdata.gps_fd);
 }
 
-static bool gps_query(/*@out@*/struct gps_data_t *gpsdata, 
+static bool gps_query(/*@out@*/struct gps_data_t *gpsdata,
 		       gps_mask_t expect,
 		       const int timeout,
 		       const char *fmt, ... )
@@ -204,7 +203,7 @@ static bool gps_query(/*@out@*/struct gps_data_t *gpsdata,
 	    if (errno == EINTR || !FD_ISSET(gpsdata->gps_fd, &rfds))
 		continue;
 	    gpsd_report(LOG_ERROR, "select %s\n", strerror(errno));
-	    exit(2);
+	    exit(EXIT_FAILURE);
 	}
 	/*@ +usedef +type +nullpass +compdef @*/
 
@@ -220,7 +219,7 @@ static bool gps_query(/*@out@*/struct gps_data_t *gpsdata,
 	if ((expect & gpsdata->set) != 0)
 	    return true;
 	else if (time(NULL) - starttime > timeout) {
-	    gpsd_report(LOG_ERROR, 
+	    gpsd_report(LOG_ERROR,
 			"timed out after %d seconds\n",
 			timeout);
 	    return false;
@@ -235,10 +234,10 @@ static void onsig(int sig)
 {
     if (sig == SIGALRM) {
 	gpsd_report(LOG_ERROR, "packet recognition timed out.\n");
-	exit(1);
+	exit(EXIT_FAILURE);
     } else {
 	gpsd_report(LOG_ERROR, "killed by signal %d\n", sig);
-	exit(0);
+	exit(EXIT_SUCCESS);
     }
 }
 
@@ -260,9 +259,9 @@ static char /*@observer@*/ *gpsd_id( /*@in@ */ struct gps_device_t *session)
 int main(int argc, char **argv)
 {
     int option, status;
-    char *device = NULL, *devtype = NULL; 
+    char *device = NULL, *devtype = NULL;
     char *speed = NULL, *control = NULL, *rate = NULL;
-    bool to_binary = false, to_nmea = false, reset = false; 
+    bool to_binary = false, to_nmea = false, reset = false;
     bool lowlevel=false, echo=false;
     struct gps_data_t gpsdata;
     const struct gps_type_t *forcetype = NULL;
@@ -290,12 +289,12 @@ int main(int argc, char **argv)
 	    control = optarg;
 	    lowlevel = true;
 	    if ((cooklen = hex_escapes(cooked, control)) <= 0) {
-		gpsd_report(LOG_ERROR, 
+		gpsd_report(LOG_ERROR,
 			    "invalid escape string (error %d)\n", (int)cooklen);
-		exit(1);
+		exit(EXIT_FAILURE);
 	    }
 #else
-	    gpsd_report(LOG_ERROR, "control_send capability has been conditioned out.\n");	    
+	    gpsd_report(LOG_ERROR, "control_send capability has been conditioned out.\n");
 #endif /* CONTROLSEND_ENABLE */
 	    break;
 	case 'e':		/* echo specified control string with wrapper */
@@ -329,7 +328,7 @@ int main(int argc, char **argv)
 #endif /* CONTROLSEND_ENABLE */
 		(void)puts((*dp)->type_name);
 	    }
-	    exit(0);
+	    exit(EXIT_SUCCESS);
 	case 'n':		/* switch to NMEA mode */
 #ifdef RECONFIGURE_ENABLE
 	    to_nmea = true;
@@ -396,11 +395,11 @@ int main(int argc, char **argv)
 	    gpsd_report(LOG_ERROR, "%d driver type names match '%s'.\n",
 			matchcount, devtype);
 	}
-    }    
+    }
 
     if (((int)to_nmea + (int)to_binary + (int)reset) > 1) {
 	gpsd_report(LOG_ERROR, "make up your mind, would you?\n");
-	exit(0);
+	exit(EXIT_SUCCESS);
     }
 
     (void) signal(SIGINT, onsig);
@@ -411,7 +410,7 @@ int main(int argc, char **argv)
     if (!lowlevel) {
 	/* Try to open the stream to gpsd. */
 	if (gps_open(NULL, NULL, &gpsdata) != 0) {
-	    gpsd_report(LOG_ERROR, "no gpsd running or network error: %s.\n", 
+	    gpsd_report(LOG_ERROR, "no gpsd running or network error: %s.\n",
 			netlib_errstr(errno));
 	    lowlevel = true;
 	}
@@ -423,19 +422,19 @@ int main(int argc, char **argv)
 
 	/* what devices have we available? */
 	if (!gps_query(&gpsdata, DEVICELIST_SET, (int)timeout, "?DEVICES;\n")) {
-	    gpsd_report(LOG_ERROR, "no DEVICES response received.\n"); 
+	    gpsd_report(LOG_ERROR, "no DEVICES response received.\n");
 	    (void)gps_close(&gpsdata);
-	    exit(1);
+	    exit(EXIT_FAILURE);
 	}
 	if (gpsdata.devices.ndevices == 0) {
-	    gpsd_report(LOG_ERROR, "no devices connected.\n"); 
+	    gpsd_report(LOG_ERROR, "no devices connected.\n");
 	    (void)gps_close(&gpsdata);
-	    exit(1);
+	    exit(EXIT_FAILURE);
 	} else if (gpsdata.devices.ndevices > 1 && device == NULL) {
-	    gpsd_report(LOG_ERROR, 
+	    gpsd_report(LOG_ERROR,
 			"multiple devices and no device specified.\n");
 	    (void)gps_close(&gpsdata);
-	    exit(1);
+	    exit(EXIT_FAILURE);
 	}
 	gpsd_report(LOG_PROG,"%d device(s) found.\n",gpsdata.devices.ndevices);
 
@@ -451,10 +450,10 @@ int main(int argc, char **argv)
 		}
 	    gpsd_report(LOG_ERROR, "specified device not found in device list.\n");
 	    (void)gps_close(&gpsdata);
-	    exit(1);
+	    exit(EXIT_FAILURE);
 	devicelist_entry_matches:;
 	}
-	(void)memcpy(&gpsdata.dev, 
+	(void)memcpy(&gpsdata.dev,
 		     &gpsdata.devices.list[i],
 		     sizeof(struct devconfig_t));
 	devcount = gpsdata.devices.ndevices;
@@ -464,7 +463,7 @@ int main(int argc, char **argv)
 	    if (gps_stream(&gpsdata, WATCH_ENABLE|WATCH_JSON, NULL) == -1) {
 		gpsd_report(LOG_ERROR, "stream set failed.\n");
 		(void)gps_close(&gpsdata);
-		exit(1);
+		exit(EXIT_FAILURE);
 	    }
 
 	    while (devcount > 0) {
@@ -472,7 +471,7 @@ int main(int argc, char **argv)
 		if (gps_read(&gpsdata) == -1) {
 		    gpsd_report(LOG_ERROR, "data read failed.\n");
 		    (void)gps_close(&gpsdata);
-		    exit(1);
+		    exit(EXIT_FAILURE);
 		}
 
 		if (gpsdata.set & DEVICE_SET) {
@@ -485,7 +484,7 @@ int main(int argc, char **argv)
 	    }
 	    gpsd_report(LOG_ERROR, "data read failed.\n");
 	    (void)gps_close(&gpsdata);
-	    exit(1);
+	    exit(EXIT_FAILURE);
 	matching_device_seen:;
 	}
 
@@ -494,7 +493,7 @@ int main(int argc, char **argv)
 	    gpsd_report(LOG_SHOUT, "%s can't be identified.\n",
 			gpsdata.dev.path);
 	    (void)gps_close(&gpsdata);
-	    exit(0);
+	    exit(EXIT_SUCCESS);
 	}
 
 	/* if no control operation was specified, just ID the device */
@@ -510,7 +509,7 @@ int main(int argc, char **argv)
 	if (reset)
 	{
 	    gpsd_report(LOG_PROG, "cannot reset with gpsd running.\n");
-	    exit(0);
+	    exit(EXIT_SUCCESS);
 	}
 
 	/*@-boolops@*/
@@ -535,7 +534,7 @@ int main(int argc, char **argv)
 	    if (strchr(speed, ':') == NULL)
 		(void)gps_query(&gpsdata,
 				DEVICE_SET, (int)timeout,
-				 "?DEVICE={\"path\":\"%s\",\"bps\":%s}\r\n", 
+				 "?DEVICE={\"path\":\"%s\",\"bps\":%s}\r\n",
 				 device, speed);
 	    else {
 		char *modespec = strchr(speed, ':');
@@ -561,23 +560,23 @@ int main(int argc, char **argv)
 		if (status == 0)
 		    (void)gps_query(&gpsdata,
 				    DEVICE_SET, (int)timeout,
-				     "?DEVICE={\"path\":\"%s\",\"bps\":%s,\"parity\":\"%c\",\"stopbits\":%c}\r\n", 
+				     "?DEVICE={\"path\":\"%s\",\"bps\":%s,\"parity\":\"%c\",\"stopbits\":%c}\r\n",
 				     device, speed, parity, stopbits);
 	    }
 	    if (atoi(speed) != (int)gpsdata.dev.baudrate) {
-		gpsd_report(LOG_ERROR, "%s driver won't support %s%c%c\n", 
+		gpsd_report(LOG_ERROR, "%s driver won't support %s%c%c\n",
 			    gpsdata.dev.path,
 			    speed, parity, stopbits);
 		status = 1;
 	    } else
-		gpsd_report(LOG_PROG, "%s change to %s%c%c succeeded\n", 
+		gpsd_report(LOG_PROG, "%s change to %s%c%c succeeded\n",
 			    gpsdata.dev.path,
 			    speed, parity, stopbits);
 	}
 	if (rate != NULL) {
-	    (void)gps_query(&gpsdata, 
+	    (void)gps_query(&gpsdata,
 			    DEVICE_SET, (int)timeout,
-			    "?DEVICE={\"path\":\"%s\",\"cycle\":%s}\n", 
+			    "?DEVICE={\"path\":\"%s\",\"cycle\":%s}\n",
 			    device, rate);
 	}
 #endif /* RECONFIGURE_ENABLE */
@@ -593,7 +592,7 @@ int main(int argc, char **argv)
 
 	if (device == NULL || forcetype == NULL) {
 		gpsd_report(LOG_ERROR, "device and type must be specified for the reset operation.\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	    }
 
 	/*@ -mustfreeonly -immediatetrans @*/
@@ -617,7 +616,7 @@ int main(int argc, char **argv)
 	    if (session.device_type->mode_switcher)
 		session.device_type->mode_switcher(&session, MODE_NMEA);
 	gpsd_wrap(&session);
-	exit(0);
+	exit(EXIT_SUCCESS);
 	/*@ +mustfreeonly +immediatetrans @*/
 #endif /* RECONFIGURE_ENABLE */
     } else {
@@ -644,7 +643,7 @@ int main(int argc, char **argv)
 
 	    if (device == NULL) {
 		gpsd_report(LOG_ERROR, "device must be specified for low-level access.\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	    }
 	    gpsd_time_init(&context, time(NULL));
 	    gpsd_init(&session, &context, device);
@@ -653,14 +652,14 @@ int main(int argc, char **argv)
 		gpsd_report(LOG_ERROR,
 			      "activation of device %s failed, errno=%d\n",
 			      device, errno);
-		exit(2);
+		exit(EXIT_FAILURE);
 	    }
 	    /* hunt for packet type and serial parameters */
 	    for (seq = 0; session.device_type == NULL; seq++) {
 		if (get_packet(&session) == ERROR_SET) {
 		    gpsd_report(LOG_ERROR,
 				"autodetection failed.\n");
-		    exit(2);
+		    exit(EXIT_FAILURE);
 		} else if (session.packet.type > COMMENT_PACKET) {
 		    gpsd_report(LOG_IO,
 				"autodetection after %d reads finds packet type %d.\n", seq, session.packet.type);
@@ -675,7 +674,7 @@ int main(int argc, char **argv)
 		gpsd_report(LOG_ERROR, "'%s' doesn't match non-generic type '%s' of selected device.\n", forcetype->type_name, session.device_type->type_name);
 	    }
 
-	    /* 
+	    /*
 	     * If we've identified this as an NMEA device, we have to eat
 	     * packets for a while to see if one of our probes elicits an
 	     * ID response telling us that it's really a SiRF or
@@ -695,7 +694,7 @@ int main(int argc, char **argv)
 
 	/* if no control operation was specified, we're done */
 	if (speed==NULL && !to_nmea && !to_binary && control==NULL)
-	    exit(0);
+	    exit(EXIT_SUCCESS);
 
 	/* maybe user wants to see the packet rather than send it */
 	if (echo)
@@ -713,14 +712,14 @@ int main(int argc, char **argv)
 	    bool write_enable = context.readonly;
 	    context.readonly = false;
 	    if (session.device_type->mode_switcher == NULL) {
-		gpsd_report(LOG_SHOUT, 
+		gpsd_report(LOG_SHOUT,
 			      "%s devices have no mode switch.\n",
 			      session.device_type->type_name);
 		status = 1;
 	    } else {
 		int target_mode = to_nmea ? MODE_NMEA : MODE_BINARY;
 
-		gpsd_report(LOG_SHOUT, 
+		gpsd_report(LOG_SHOUT,
 			      "switching to mode %s.\n",
 			    to_nmea ? "NMEA" : "BINARY");
 		session.device_type->mode_switcher(&session, target_mode);
@@ -756,17 +755,17 @@ int main(int argc, char **argv)
 	    }
 	    if (status == 0) {
 		if (session.device_type->speed_switcher == NULL) {
-		    gpsd_report(LOG_ERROR, 
+		    gpsd_report(LOG_ERROR,
 				"%s devices have no speed switch.\n",
 				session.device_type->type_name);
 		    status = 1;
 		}
-		else if (session.device_type->speed_switcher(&session, 
+		else if (session.device_type->speed_switcher(&session,
 							     (speed_t)atoi(speed),
-							     parity, 
+							     parity,
 							     stopbits)) {
 		    settle(&session);
-		    gpsd_report(LOG_PROG, "%s change to %s%c%d succeeded\n", 
+		    gpsd_report(LOG_PROG, "%s change to %s%c%d succeeded\n",
 			    session.gpsdata.dev.path,
 			    speed, parity, stopbits);
 		} else {
@@ -781,7 +780,7 @@ int main(int argc, char **argv)
 	    bool write_enable = context.readonly;
 	    context.readonly = false;
 	    if (session.device_type->rate_switcher == NULL) {
-		gpsd_report(LOG_ERROR, 
+		gpsd_report(LOG_ERROR,
 			      "%s devices have no rate switcher.\n",
 			      session.device_type->type_name);
 		status = 1;
@@ -803,13 +802,13 @@ int main(int argc, char **argv)
 	    bool write_enable = context.readonly;
 	    context.readonly = false;
 	    if (session.device_type->control_send == NULL) {
-		gpsd_report(LOG_ERROR, 
+		gpsd_report(LOG_ERROR,
 			      "%s devices have no control sender.\n",
 			      session.device_type->type_name);
 		status = 1;
 	    } else {
-		if (session.device_type->control_send(&session, 
-						      cooked, 
+		if (session.device_type->control_send(&session,
+						      cooked,
 						      (size_t)cooklen) == -1) {
 		    gpsd_report(LOG_ERROR, "control transmission failed.\n");
 		    status = 1;
