@@ -15,7 +15,6 @@
 #include <signal.h>
 #include <stdarg.h>
 #include <time.h>
-#include <termios.h>
 #include <sys/time.h>		/* expected to declare select(2) a la SuS */
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -151,7 +150,7 @@ static void visibilize(/*@out@*/char *buf2, size_t len, const char *buf)
 
     buf2[0] = '\0';
     for (sp = buf; *sp != '\0' && strlen(buf2)+4 < len; sp++)
-	if (isprint(*sp) || (sp[0] == '\n' && sp[1] == '\0') 
+	if (isprint(*sp) || (sp[0] == '\n' && sp[1] == '\0')
 	  || (sp[0] == '\r' && sp[2] == '\0'))
 	    (void)snprintf(buf2 + strlen(buf2), 2, "%c", *sp);
 	else
@@ -386,7 +385,8 @@ static bool switch_type(const struct gps_type_t *devtype)
     }
     if (newobject) {
 	if (LINES < (*newobject)->min_y + 1 || COLS < (*newobject)->min_x) {
-	    monitor_complain("New type requires %dx%d screen",
+	    monitor_complain("%s requires %dx%d screen",
+			     (*newobject)->driver->type_name,
 			     (*newobject)->min_x, (*newobject)->min_y + 1);
 	} else {
 	    int leftover;
@@ -502,15 +502,15 @@ int main(int argc, char **argv)
 		(void)fputs((*active)->driver->type_name, stdout);
 		(void)fputc('\n', stdout);
 	    }
-	    exit(0);
+	    exit(EXIT_SUCCESS);
 	case 'V':
 	    (void)printf("gpsmon: %s (revision %s)\n", VERSION, REVISION);
-	    exit(0);
+	    exit(EXIT_SUCCESS);
 	case 'l':		/* enable logging at startup */
 	    logfile = fopen(optarg, "w");
 	    if (logfile == NULL) {
 		(void)fprintf(stderr, "Couldn't open logfile for writing.\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	    }
 	    break;
         case 't':
@@ -522,13 +522,13 @@ int main(int argc, char **argv)
 		    matches++;
 		}
 	    }
-	    if (matches > 1) { 
+	    if (matches > 1) {
 		(void)fprintf(stderr, "-T option matched more than one driver.\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	    }
-	    else if (matches == 0) { 
+	    else if (matches == 0) {
 		(void)fprintf(stderr, "-T option didn't match any driver.\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	    }
 	    active = NULL;
 	    break;
@@ -542,7 +542,7 @@ int main(int argc, char **argv)
 		fputs
 		("usage:  gpsmon [-?hVln] [-D debuglevel] [-t type] [server[:port:[device]]]\n",
 		 stderr);
-	    exit(1);
+	    exit(EXIT_FAILURE);
 	}
     }
     /*@ +branchstate @*/
@@ -570,7 +570,7 @@ int main(int argc, char **argv)
 			  argv[0], source.server, source.port,
 			  session.gpsdata.gps_fd,
 			  netlib_errstr(session.gpsdata.gps_fd));
-	    exit(1);
+	    exit(EXIT_FAILURE);
 	}
 	if (source.device != NULL) {
 	    if (nmea) {
@@ -601,7 +601,7 @@ int main(int argc, char **argv)
 	    gpsd_report(LOG_ERROR,
 			"activation of device %s failed, errno=%d\n",
 			session.gpsdata.dev.path, errno);
-	    exit(2);
+	    exit(EXIT_FAILURE);
 	}
 
 	serial = true;
@@ -624,7 +624,7 @@ int main(int argc, char **argv)
 	(void)endwin();
 	(void)fputs("gpsmon: assertion failure, probable I/O error\n",
 		    stderr);
-	exit(1);
+	exit(EXIT_FAILURE);
     }
 
     (void)initscr();
@@ -688,7 +688,7 @@ int main(int argc, char **argv)
 		(void)wprintw(cmdwin, type_name);
 		(void)wprintw(cmdwin, "> ");
 		(void)wclrtoeol(cmdwin);
-		if (active != NULL 
+		if (active != NULL
 			&& len > 0 && session.packet.outbuflen > 0
 			&& (*active)->update != NULL)
 		    (*active)->update();
@@ -1016,7 +1016,7 @@ int main(int argc, char **argv)
 
     if (explanation != NULL)
 	(void)fputs(explanation, stderr);
-    exit(0);
+    exit(EXIT_SUCCESS);
 }
 
 /* gpsmon.c ends here */
