@@ -1,4 +1,4 @@
-/* 
+/*
  * ntpshm.c - put time information in SHM segment for xntpd
  * struct shmTime and getShmTime from file in the xntp distribution:
  *	sht.c - Testprogram for shared memory refclock
@@ -40,11 +40,11 @@
 struct shmTime
 {
     int mode;			/* 0 - if valid set
-				 *       use values, 
+				 *       use values,
 				 *       clear valid
-				 * 1 - if valid set 
+				 * 1 - if valid set
 				 *       if count before and after read of values is equal,
-				 *         use values 
+				 *         use values
 				 *       clear valid
 				 */
     int count;
@@ -70,8 +70,8 @@ struct shmTime
  *
  * Segments 2 and 3: permissions 0666, i.e. other programs can read
  *                   and write as any user.  I.e.: if ntpd has been
- *                   configured to use these segments, any 
- *                   unpriviliged user is allowed to provide data 
+ *                   configured to use these segments, any
+ *                   unpriviliged user is allowed to provide data
  *                   for synchronisation.
  *
  * As gpsd can be started as both root and non-root, this behaviour is
@@ -129,7 +129,7 @@ static /*@null@*/ volatile struct shmTime *getShmTime(int unit)
 	perms = 0666;
     }
 
-    /* 
+    /*
      * Note: this call requires root under BSD, and possibly on
      * well-secured Linux systems.  This is why ntpshm_init() has to be
      * called before privilege-dropping.
@@ -141,7 +141,7 @@ static /*@null@*/ volatile struct shmTime *getShmTime(int unit)
 		    (long int)(NTPD_BASE + unit), sizeof(struct shmTime),
 		    (int)perms, strerror(errno));
 	return NULL;
-    } 
+    }
     p = (struct shmTime *)shmat(shmid, 0, 0);
     /*@ -mustfreefresh */
     if ((int)(long)p == -1) {
@@ -212,7 +212,7 @@ int ntpshm_put(struct gps_device_t *session, double fixtime, double fudge)
 /* put a received fix time into shared memory for NTP */
 {
     /* shmTime is volatile to try to prevent C compiler from reordering
-     * writes, or optimizing some 'dead code'.  but CPU cache may still 
+     * writes, or optimizing some 'dead code'.  but CPU cache may still
      *write out of order since we do not use memory barriers, yet */
     volatile struct shmTime *shmTime = NULL;
     struct timeval tv;
@@ -237,7 +237,7 @@ int ntpshm_put(struct gps_device_t *session, double fixtime, double fudge)
      *
      * ntpd does this:
      *
-     * reads valid.  
+     * reads valid.
      * IFF valid is 1
      *    reads count
      *    reads values
@@ -245,7 +245,7 @@ int ntpshm_put(struct gps_device_t *session, double fixtime, double fudge)
      *    IFF count unchanged
      *        use values
      *    clear valid
-     *    
+     *
      */
     shmTime->valid = 0;
     shmTime->count++;
@@ -258,7 +258,7 @@ int ntpshm_put(struct gps_device_t *session, double fixtime, double fudge)
     shmTime->leap = session->context->leap_notify;
     /* setting the precision here does not seem to help anything, too
      * hard to calculate properly anyway.  Let ntpd figure it out.
-     * Any NMEA will be about -1 or -2. 
+     * Any NMEA will be about -1 or -2.
      * Garmin GPS-18/USB is around -6 or -7.
      */
     /* FIXME need a memory barrier here to prevent write reordering by
@@ -288,7 +288,7 @@ int ntpshm_put(struct gps_device_t *session, double fixtime, double fudge)
  *  4    20    DTR  --> Data Terminal Ready
  *  1     8    DCD  <-- Data Carrier Detect
  *  9    22    RI   <-- Ring Indicator
- *  5     7    SG       Signal ground 
+ *  5     7    SG       Signal ground
  */
 
 /*@unused@*//* splint is confused here */
@@ -343,7 +343,7 @@ static int ntpshm_pps(struct gps_device_t *session, struct timeval *tv)
      *
      * ntpd does this:
      *
-     * reads valid.  
+     * reads valid.
      * IFF valid is 1
      *    reads count
      *    reads values
@@ -351,7 +351,7 @@ static int ntpshm_pps(struct gps_device_t *session, struct timeval *tv)
      *    IFF count unchanged
      *        use values
      *    clear valid
-     *    
+     *
      */
     shmTimeP->valid = 0;
     shmTimeP->count++;
@@ -366,7 +366,7 @@ static int ntpshm_pps(struct gps_device_t *session, struct timeval *tv)
     shmTimeP->count++;
     shmTimeP->valid = 1;
 
-    /* this is more an offset jitter/dispersion than precision, 
+    /* this is more an offset jitter/dispersion than precision,
      * but still useful for debug */
     precision = offset != 0 ? (int)(ceil(log(offset) / M_LN2)) : -20;
     gpsd_report(LOG_RAW, "PPS ntpshm_pps %lu.%03lu @ %lu.%06lu, preci %d\n",
@@ -377,8 +377,8 @@ static int ntpshm_pps(struct gps_device_t *session, struct timeval *tv)
 }
 
 /*
- * Warning: This is a potential portability problem. 
- * It's needed so that TIOCMIWAIT will be defined and the serial-PPS 
+ * Warning: This is a potential portability problem.
+ * It's needed so that TIOCMIWAIT will be defined and the serial-PPS
  * code will work, but it's not a SuS/POSIX standard header.  We're
  * going to include it unconditionally here because we expect both
  * Linux and BSD to have it and we want compilation to break with
@@ -464,7 +464,7 @@ static int init_kernel_pps(struct gps_device_t *session) {
      * (/sys/class/pps/pps?/path is just a link to that)
      * to find the /dev/pps? that matches our serial port.
      * this code fails if there are more then 10 pps devices.
-     *     
+     *
      * yes, this could be done with libsysfs, but trying to keep the
      * number of required libs small */
     memset( (void *)&globbuf, 0, sizeof(globbuf));
@@ -507,7 +507,7 @@ static int init_kernel_pps(struct gps_device_t *session) {
 	    , path, strerror(errno));
     	return -1;
     }
-    /* root privs are not required past this point */ 
+    /* root privs are not required past this point */
 
     if ( 0 > time_pps_create(ret, &session->kernelpps_handle )) {
 	gpsd_report(LOG_INF, "KPPS time_pps_create(%d) failed: %s\n"
@@ -528,7 +528,7 @@ static int init_kernel_pps(struct gps_device_t *session) {
         pp.mode = PPS_CAPTUREBOTH;
 
         if ( 0 > time_pps_setparams(session->kernelpps_handle, &pp)) {
-	    gpsd_report(LOG_ERROR, 
+	    gpsd_report(LOG_ERROR,
 		"KPPS time_pps_setparams() failed: %s\n", strerror(errno));
 	    time_pps_destroy(session->kernelpps_handle);
 	    return -1;
@@ -574,7 +574,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
     gpsd_report(LOG_PROG, "PPS Create Thread gpsd_ppsmonitor\n");
 
     /* wait for the device to go active - makes this safe to call early */
-    while (session->gpsdata.gps_fd == -1) {
+    while (BAD_SOCKET(session->gpsdata.gps_fd)) {
 	/* should probably remove this once code is verified */
 	gpsd_report(LOG_PROG, "PPS thread awaiting device activation\n");
 	(void)sleep(1);
@@ -589,7 +589,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
     }
 
     if ( 0 == getuid() ) {
-	/* this case will fire on command-line devices; 
+	/* this case will fire on command-line devices;
 	 * they're opened before priv-dropping.  Matters because
          * only root can use /var/run.
 	 */
@@ -624,8 +624,8 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 
     /* root privileges are not required after this point */
 
-    /* 
-     * Wait for status change on any handshake line. The only assumption here 
+    /*
+     * Wait for status change on any handshake line. The only assumption here
      * is that no GPS lights up more than one of these pins.  By waiting on
      * all of them we remove a configuration switch.
      */
@@ -645,7 +645,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 
 /*@-noeffect@*/
 #ifdef HAVE_CLOCK_GETTIME
-	/* using  clock_gettime() here, that is nSec, 
+	/* using  clock_gettime() here, that is nSec,
 	 * not uSec like gettimeofday */
 	if ( 0 > clock_gettime(CLOCK_REALTIME, &ts) ) {
 	    /* uh, oh, can not get time! */
@@ -666,7 +666,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 #if defined(HAVE_SYS_TIMEPPS_H)
         if ( 0 <= session->kernelpps_handle ) {
 	    struct timespec kernelpps_tv;
-	    /* on a quad core 2.4GHz Xeon this removes about 20uS of 
+	    /* on a quad core 2.4GHz Xeon this removes about 20uS of
 	     * latency, and about +/-5uS of jitter over the other method */
             memset( (void *)&kernelpps_tv, 0, sizeof(kernelpps_tv));
 	    if ( 0 > time_pps_fetch(session->kernelpps_handle, PPS_TSFMT_TSPEC
@@ -693,7 +693,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 		       pi.assert_timestamp.tv_nsec,
 		       pi.assert_sequence,
 		       pi.clear_timestamp.tv_sec,
-		       pi.clear_timestamp.tv_nsec, 
+		       pi.clear_timestamp.tv_nsec,
 		       pi.clear_sequence);
 		gpsd_report(LOG_PROG, "KPPS data: using %s\n",
 		       kpps_edge ? "assert" : "clear");
@@ -706,10 +706,10 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 		    duration_kpps = 0;
 		}
 #undef timediff_kpps
-	        gpsd_report(LOG_INF, 
+	        gpsd_report(LOG_INF,
 		    "KPPS cycle: %7d, duration: %7d @ %lu.%09lu\n",
 		    cycle_kpps, duration_kpps,
-		    (unsigned long)tv_kpps.tv_sec, 
+		    (unsigned long)tv_kpps.tv_sec,
 		    (unsigned long)tv_kpps.tv_nsec);
 		pulse_kpps[kpps_edge] = tv_kpps;
 		ok = true;
@@ -875,7 +875,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 #endif
 	    {
 		sample.tv = tv; 	/* structure copy */
-	    } 
+	    }
 	    /* FIXME!! this is wrong if signal is 5Hz or 10Hz instead of PPS */
 	    /* careful, Unix time to nSec is more precision than a double */
 	    sample.offset = 1 + session->last_fixtime - ts.tv_sec;
@@ -903,7 +903,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	    } else {
 	    	log1 = "skipped ship_to_ntp=0";
 	    }
-	    gpsd_report(LOG_RAW, 
+	    gpsd_report(LOG_RAW,
 		    "PPS edge %.20s %lu.%06lu offset %.9f\n",
 		    log1,
 		    (unsigned long)sample.tv.tv_sec,
