@@ -1267,7 +1267,7 @@ static void nextstate(struct gps_packet_t *lexer, unsigned char c)
 	    lexer->state = JSON_STRINGLITERAL;
 	    lexer->json_after = JSON_END_ATTRIBUTE;
 	} else {
-	    gpsd_report(LOG_RAW + 2, 
+	    gpsd_report(LOG_RAW + 2,
 			"%08ld: missing attribute start after header\n",
 			lexer->char_counter);
 	    lexer->state = GROUND_STATE;
@@ -1634,6 +1634,7 @@ void packet_parse(struct gps_packet_t *lexer)
 #ifdef TSIP_ENABLE
 		/* check for some common TSIP packet types:
 		 * 0x13, TSIP Parsing Error Notification
+		 * 0x38, Request SV system data
 		 * 0x41, GPS time, data length 10
 		 * 0x42, Single Precision Fix, data length 16
 		 * 0x43, Velocity Fix, data length 20
@@ -1663,7 +1664,7 @@ void packet_parse(struct gps_packet_t *lexer)
 		/*@ +charint @*/
 		pkt_id = lexer->inbuffer[1];	/* packet ID */
                 /* *INDENT-OFF* */
-		if (!((0x13 == pkt_id) || (0xbb == pkt_id) || (0xbc == pkt_id))
+		if (!((0x13 == pkt_id) || (0xbb == pkt_id) || (0xbc == pkt_id)  || (0x38 == pkt_id))
 		    && ((0x41 > pkt_id) || (0x8f < pkt_id))) {
 		    gpsd_report(LOG_IO,
 				"Packet ID 0x%02x out of range for TSIP\n",
@@ -1674,6 +1675,8 @@ void packet_parse(struct gps_packet_t *lexer)
 		/*@ -ifempty */
 		if ((0x13 == pkt_id) && (0x01 <= packetlen))
 		    /* pass */ ;
+		else if ((0x38 == pkt_id) && (0x03 == packetlen))
+		    /* pass */ ;
 		else if ((0x41 == pkt_id)
 			 && ((0x0e == packetlen) || (0x0f == packetlen)))
 		    /* pass */ ;
